@@ -45,19 +45,24 @@ Enjoy!
 
 """
 
+# Standard library imports
+import copy
 import logging
 import os
 import platform
 import sys
 import warnings
-import copy
+
+# Local imports
+from qdarkstyle.palette import DarkPalette
 
 if sys.version_info >= (3, 4):
     import importlib
 
-__version__ = "2.6.4"
+__version__ = "2.7"
 
 
+# Constants
 QT_BINDINGS = ['PyQt4', 'PyQt5', 'PySide', 'PySide2']
 """list: values of all Qt bindings to import."""
 
@@ -82,6 +87,33 @@ QT_BINDING = 'Not set or nonexistent'
 QT_ABSTRACTION = 'Not set or nonexistent'
 """str: Qt abstraction layer in use."""
 
+# Folder's path
+REPO_PATH = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
+
+EXAMPLE_PATH = os.path.join(REPO_PATH, 'example')
+IMAGES_PATH = os.path.join(REPO_PATH, 'images')
+PACKAGE_PATH = os.path.join(REPO_PATH, 'qdarkstyle')
+
+QSS_PATH = os.path.join(PACKAGE_PATH, 'qss')
+RC_PATH = os.path.join(PACKAGE_PATH, 'rc')
+SVG_PATH = os.path.join(PACKAGE_PATH, 'svg')
+
+# File names
+QSS_FILE = 'style.qss'
+QRC_FILE = QSS_FILE.replace('.qss', '.qrc')
+
+MAIN_SCSS_FILE = 'main.scss'
+STYLES_SCSS_FILE = '_styles.scss'
+VARIABLES_SCSS_FILE = '_variables.scss'
+
+# File paths
+QSS_FILEPATH = os.path.join(PACKAGE_PATH, QSS_FILE)
+QRC_FILEPATH = os.path.join(PACKAGE_PATH, QRC_FILE)
+
+MAIN_SCSS_FILEPATH = os.path.join(QSS_PATH, MAIN_SCSS_FILE)
+STYLES_SCSS_FILEPATH = os.path.join(QSS_PATH, STYLES_SCSS_FILE)
+VARIABLES_SCSS_FILEPATH = os.path.join(QSS_PATH, VARIABLES_SCSS_FILE)
+
 
 def _logger():
     return logging.getLogger('qdarkstyle')
@@ -125,6 +157,36 @@ def _qt_wrapper_import(qt_api):
         return loader
 
 
+def _apply_stylesheet_patches(stylesheet):
+    """Apply OS specific stylesheet pacthes."""
+    # See issue #12
+    if platform.system().lower() == 'darwin':
+        mac_fix = '''
+        QDockWidget::title
+        {{
+            background-color: {color};
+            text-align: center;
+            height: 12px;
+        }}
+        '''.format(color=DarkPalette.COLOR_BACKGROUND_NORMAL)
+        stylesheet += mac_fix
+
+    return stylesheet
+
+
+def _apply_palette_fix(QCoreApplication, QPalette, QColor):
+    """Apply application level fixes on the QPalette."""
+    # See issue #139
+    color = DarkPalette.COLOR_SELECTION_LIGHT
+    qcolor = QColor(color)
+    app = QCoreApplication.instance()
+
+    if app:
+        palette = app.palette()
+        palette.setColor(QPalette.Normal, QPalette.Link, qcolor)
+        app.setPalette(palette)
+
+
 def load_stylesheet_from_environment(is_pyqtgraph=False):
     """
     Load the stylesheet from QT_API (or PYQTGRAPH_QT_LIB) environment variable.
@@ -211,10 +273,10 @@ def load_stylesheet(pyside=True):
     warnings.warn(
         "load_stylesheet() will not receive pyside parameter in version 3. "
         "Set QtPy environment variable to specify the Qt binding insteady.",
-        FutureWarning
+        PendingDeprecationWarning
     )
-    # Smart import of the rc file
 
+    # Smart import of the rc file
     pyside_ver = None
 
     if pyside:
@@ -222,7 +284,7 @@ def load_stylesheet(pyside=True):
         # Detect the PySide version available
         try:
             import PySide
-        except ImportError: # Compatible with py27
+        except ImportError:  # Compatible with py27
             import PySide2
             pyside_ver = 2
         else:
@@ -237,12 +299,18 @@ def load_stylesheet(pyside=True):
 
     # Load the stylesheet content from resources
     if not pyside:
-        from PyQt4.QtCore import QFile, QTextStream
+        from PyQt4.QtCore import QCoreApplication, QFile, QTextStream
+        from PyQt4.QtGui import QColor, QPalette
     else:
         if pyside_ver == 1:
-            from PySide.QtCore import QFile, QTextStream
+            from PySide.QtCore import QCoreApplication, QFile, QTextStream
+            from PySide.QtGui import QColor, QPalette
         else:
-            from PySide2.QtCore import QFile, QTextStream
+            from PySide2.QtCore import QCoreApplication, QFile, QTextStream
+            from PySide2.QtGui import QColor, QPalette
+
+    # Apply palette fix. See issue #139
+    _apply_palette_fix(QCoreApplication, QPalette, QColor)
 
     f = QFile(":qdarkstyle/style.qss")
     if not f.exists():
@@ -253,16 +321,10 @@ def load_stylesheet(pyside=True):
         f.open(QFile.ReadOnly | QFile.Text)
         ts = QTextStream(f)
         stylesheet = ts.readAll()
-        if platform.system().lower() == 'darwin':  # see issue #12 on github
-            mac_fix = '''
-            QDockWidget::title
-            {
-                background-color: #31363b;
-                text-align: center;
-                height: 12px;
-            }
-            '''
-            stylesheet += mac_fix
+
+        # Apply OS specific patches
+        stylesheet = _apply_stylesheet_patches(stylesheet)
+
         return stylesheet
 
 
@@ -325,11 +387,16 @@ def load_stylesheet_pyqt5():
         "use load_stylesheet()",
         PendingDeprecationWarning
     )
+
     # Smart import of the rc file
     import qdarkstyle.pyqt5_style_rc
 
     # Load the stylesheet content from resources
-    from PyQt5.QtCore import QFile, QTextStream
+    from PyQt5.QtCore import QCoreApplication, QFile, QTextStream
+    from PyQt5.QtGui import QColor, QPalette
+
+    # Apply palette fix. See issue #139
+    _apply_palette_fix(QCoreApplication, QPalette, QColor)
 
     f = QFile(":qdarkstyle/style.qss")
     if not f.exists():
@@ -340,113 +407,12 @@ def load_stylesheet_pyqt5():
         f.open(QFile.ReadOnly | QFile.Text)
         ts = QTextStream(f)
         stylesheet = ts.readAll()
-        if platform.system().lower() == 'darwin':  # see issue #12 on github
-            mac_fix = '''
-            QDockWidget::title
-            {
-                background-color: #31363b;
-                text-align: center;
-                height: 12px;
-            }
-            '''
-            stylesheet += mac_fix
+
+        # Apply OS specific patches
+        # stylesheet = _apply_stylesheet_patches(stylesheet)
         return stylesheet
 
 
-def information():
-    """Get system and runtime information."""
-    info = []
-    qt_api = ''
-    qt_lib = ''
-    qt_bin = ''
-
-    try:
-        qt_api = os.environ['QT_API']
-    except KeyError:
-        qt_api = 'Not set or nonexistent'
-
-    try:
-        from Qt import __binding__
-    except Exception:
-        # It should be (KeyError, ModuleNotFoundError, ImportError)
-        # but each python version have a different one, and not define others
-        qt_lib = 'Not set or nonexistent'
-    else:
-        qt_lib = __binding__
-
-    try:
-        qt_bin = os.environ['PYQTGRAPH_QT_LIB']
-    except KeyError:
-        qt_bin = 'Not set or nonexistent'
-
-    info.append('QDarkStyle: %s' % __version__)
-    info.append('OS: %s %s %s' % (platform.system(), platform.release(), platform.machine()))
-    info.append('Platform: %s' % sys.platform)
-    info.append('Python: %s' % '.'.join(str(e) for e in sys.version_info[:]))
-    info.append('Python API: %s' % sys.api_version)
-
-    info.append('Binding in use:     %s' % QT_BINDING)
-    info.append('Abstraction in use: %s' % QT_ABSTRACTION)
-
-    info.append('qtpy (QT_API):                %s' % qt_api)
-    info.append('pyqtgraph (PYQTGRAPH_QT_LIB): %s' % qt_lib)
-    info.append('Qt.py (__binding__):          %s' % qt_bin)
-
-    return info
-
-
-def qt_bindings():
-    """Return a list of qt bindings available."""
-    return _check_imports(import_list=QT_BINDINGS)
-
-
-def qt_abstractions():
-    """Return a list of qt abstraction layers available."""
-    return _check_imports(import_list=QT_ABSTRACTIONS)
-
-
-def _check_imports(import_list):
-    """Return a list of imports available."""
-
-    # Disable warnings here
-    warnings.filterwarnings("ignore")
-
-    import_list_return = copy.deepcopy(import_list)
-    # Using import_list_return var in for, does not work in py2.7
-    # when removing the element, it reflects on for list
-    # so it skips next element
-    for current_import in import_list:
-
-        spec = True
-        # Copy the sys path to make sure to not insert anything
-        sys_path = sys.path
-
-        # Check import
-        if sys.version_info >= (3, 4):
-            spec = importlib.util.find_spec(current_import)
-        else:
-            try:
-                __import__(current_import)
-            except RuntimeWarning:
-                spec = True
-            except Exception:
-                spec = None
-            else:
-                spec = True
-
-        if spec is None:
-            # Remove if not available
-            import_list_return.remove(current_import)
-
-        # Restore sys path
-        sys.path = sys_path
-
-    # Restore warnings
-    warnings.resetwarnings()
-
-    return import_list_return
-
-
 def _import_qt_modules_from(use_binding='pyqt5', use_abstraction='qtpy'):
     """New approach to import modules using importlib."""
 
